/**
 * Arduino Sketch für SmartHome yourself - Arduino Lehrgang
 * 
 * Tag 2: Digitalen GPIO schalten
 * Mit diesem Sketch lassen wir eine extern angeschlossene LED 
 * und die Onboard-LED abwechselnd blinken
 * 
 * https://www.arduino.cc/reference/de/language/structure/sketch/setup/
 * https://www.arduino.cc/reference/de/language/structure/sketch/loop/
 * https://www.arduino.cc/reference/de/language/functions/digital-io/pinmode/
 * https://www.arduino.cc/reference/de/language/functions/digital-io/digitalwrite/
 * https://www.arduino.cc/reference/de/language/functions/time/delay/
 * 
 * By Daniel Scheidler - Dezember 2019
 */


/**
 * Die setup()-Methode wird immer genau einmal als erstes bei Einschalten des Arduino durchlaufen.
 * Sie dient zur initialisierung des Programms.
 */
void setup() {
  pinMode(LED_BUILTIN, OUTPUT);       // Pin D13 (OnBoard-LED) als Ausgang definieren
                                      // LED_BUILTIN ist eine Standard-Konstante der Arduino Software. 
                                      // Sie steht für den GPIO D13.
  pinMode(3, OUTPUT);                 // Pin D3 (Rote-LED) als Ausgang definieren
                                      // Das "D" der digitalen GPIO kann bei der Pin-Angabe weggelassen werden. 
                                      // Bei analogen GPIOs muss das führende "A" jedoch immer mit angegeben werden.
}


/**
 * Die loop()-Methode wird nach durchlaufen der setup()-Methode immer wiederholt, 
 * bis der Arduino ausgeschaltet wird. 
 */
void loop() {
  digitalWrite(LED_BUILTIN, HIGH);  // OnBoard-LED einschalten
  delay(1000);                      // eine Sekunde warten

  digitalWrite(LED_BUILTIN, LOW);   // OnBoard-LED ausschalten
  delay(1000);                      // eine Sekunde warten

  digitalWrite(3, HIGH);            // LED an PIN D3 einschalten
  delay(1000);                      // eine Sekunde warten

  digitalWrite(3, LOW);             // LED an PIN D3 ausschalten
  delay(1000);                      // eine Sekunde warten
}
